timeutil

package
v1.3.14 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package timeutil provides time-related utility functions.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func JitterTime

func JitterTime(base time.Duration, maxJitterPct float64) time.Duration

JitterTime subtracts a random percentage from the base time to introduce jitter. maxJitterPct must be in the range [0, 1). This is useful for preventing thundering herd problems when multiple clients reconnect or send keepalives at the same time.

Types

This section is empty.

Jump to