Documentation
¶
Overview ¶
Package timeutil provides time-related utility functions.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func JitterTime ¶
JitterTime subtracts a random percentage from the base time to introduce jitter. maxJitterPct must be in the range [0, 1). This is useful for preventing thundering herd problems when multiple clients reconnect or send keepalives at the same time.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.